@@ -43,28 +43,35 @@ class ApiUnous:
 
     def notificar(self):
         params = {
-            "EnterpriseKey": self._mindset_user,
-            "enterprisePwd": self._mindset_pass,
-            "jobName": 'CleanUpJob'
+            'EnterpriseKey': self._mindset_user,
+            'enterprisePwd': self._mindset_pass,
+            'jobName': 'CleanUpJob',
         }
         response = requests.get(url=self._mindset_notify_url, params=params)
-        retorno = {
-            "ok": response.ok,
-            "notificou": response.text == '<boolean xmlns="http://schemas.microsoft.com/2003/10/Serialization/">true</boolean>'
+        return {
+            'ok': response.ok,
+            'notificou': response.json().get('StatusReply', '') == 0,
         }
-        return retorno
 
     def _integrar(self, data, url_endpoint):
         url = self._mindset_url + url_endpoint
         offset = 0
         limit = 10000
         for i in range(int(len(data) / limit) + 1):
-            response = requests.post(url=url, data=json.dumps(data[offset:offset + limit], cls=DecimalEncoder),
-                                     headers=self.headers)
-            if not response.ok:
-                break
+            conteudo_a_integrar = data[offset:offset + limit]
+            conteudo_integrado = len(conteudo_a_integrar)
+            if conteudo_integrado > 0:
+                response = requests.post(
+                    url=url,
+                    data=json.dumps(conteudo_a_integrar, cls=DecimalEncoder),
+                    headers=self.headers,
+                )
+                if not response.ok:
+                    break
             offset += limit
+            print(f'{conteudo_integrado} REGISTROS INTEGRADOS')
             time.sleep(5)
+        print('------------------------------------------')
         return response.ok, response.json()
 
     def limpar_pedidos(self):
@@ -73,10 +80,10 @@ class ApiUnous:
 
     def _get_token(self):
         response = requests.get(url=self._mindset_url + '/Auth/token', data={
-            "grant_type": self._grant_type,
-            "username": self._mindset_user,
-            "password": self._mindset_pass,
-            "client_id": self._client_id
+            'grant_type': self._grant_type,
+            'username': self._mindset_user,
+            'password': self._mindset_pass,
+            'client_id': self._client_id
         })
         return json.loads(response.text).get('access_token')
 
